diff --git a/core/lib/Drupal/Core/Entity/DatabaseStorageController.php b/core/lib/Drupal/Core/Entity/DatabaseStorageController.php
index 744eb23..6e703c7 100644
--- a/core/lib/Drupal/Core/Entity/DatabaseStorageController.php
+++ b/core/lib/Drupal/Core/Entity/DatabaseStorageController.php
@@ -288,7 +288,7 @@ protected function buildPropertyQuery(QueryInterface $entity_query, array $value
    *   A SelectQuery object for loading the entity.
    */
   protected function buildQuery($ids, $revision_id = FALSE) {
-    $query = $this->database->select($this->entityInfo['base_table'], 'base');
+    $query = $this->database->select($this->entityInfo['baseTable'], 'base');
 
     $query->addTag($this->entityType . '_load_multiple');
 
@@ -300,7 +300,7 @@ protected function buildQuery($ids, $revision_id = FALSE) {
     }
 
     // Add fields from the {entity} table.
-    $entity_fields = drupal_schema_fields_sql($this->entityInfo['base_table']);
+    $entity_fields = drupal_schema_fields_sql($this->entityInfo['baseTable']);
 
     if ($this->revisionKey) {
       // Add all fields from the {entity_revision} table.
@@ -409,7 +409,7 @@ public function delete(array $entities) {
       }
       $ids = array_keys($entities);
 
-      $this->database->delete($this->entityInfo['base_table'])
+      $this->database->delete($this->entityInfo['baseTable'])
         ->condition($this->idKey, $ids, 'IN')
         ->execute();
 
@@ -455,7 +455,7 @@ public function save(EntityInterface $entity) {
 
       if (!$entity->isNew()) {
         if ($entity->isDefaultRevision()) {
-          $return = drupal_write_record($this->entityInfo['base_table'], $entity, $this->idKey);
+          $return = drupal_write_record($this->entityInfo['baseTable'], $entity, $this->idKey);
         }
         else {
           // @todo, should a different value be returned when saving an entity
@@ -472,7 +472,7 @@ public function save(EntityInterface $entity) {
         $this->invokeHook('update', $entity);
       }
       else {
-        $return = drupal_write_record($this->entityInfo['base_table'], $entity);
+        $return = drupal_write_record($this->entityInfo['baseTable'], $entity);
         if ($this->revisionKey) {
           $this->saveRevision($entity);
         }
@@ -525,7 +525,7 @@ protected function saveRevision(EntityInterface $entity) {
     if ($entity->isNewRevision()) {
       drupal_write_record($this->revisionTable, $record);
       if ($entity->isDefaultRevision()) {
-        $this->database->update($this->entityInfo['base_table'])
+        $this->database->update($this->entityInfo['baseTable'])
           ->fields(array($this->revisionKey => $record[$this->revisionKey]))
           ->condition($this->idKey, $entity->id())
           ->execute();
diff --git a/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php b/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php
index 42ea348..c6388f1 100644
--- a/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php
+++ b/core/lib/Drupal/Core/Entity/DatabaseStorageControllerNG.php
@@ -166,7 +166,7 @@ protected function buildPropertyQuery(QueryInterface $entity_query, array $value
    * {@inheritdoc}
    */
   protected function buildQuery($ids, $revision_id = FALSE) {
-    $query = $this->database->select($this->entityInfo['base_table'], 'base');
+    $query = $this->database->select($this->entityInfo['baseTable'], 'base');
     $is_revision_query = $this->revisionKey && ($revision_id || !$this->dataTable);
 
     $query->addTag($this->entityType . '_load_multiple');
@@ -179,7 +179,7 @@ protected function buildQuery($ids, $revision_id = FALSE) {
     }
 
     // Add fields from the {entity} table.
-    $entity_fields = drupal_schema_fields_sql($this->entityInfo['base_table']);
+    $entity_fields = drupal_schema_fields_sql($this->entityInfo['baseTable']);
 
     if ($is_revision_query) {
       // Add all fields from the {entity_revision} table.
@@ -291,7 +291,7 @@ protected function attachPropertyData(array &$entities, $revision_id = FALSE) {
       $field_definition = \Drupal::entityManager()->getFieldDefinitions($this->entityType);
       $translations = array();
       if ($this->revisionTable) {
-        $data_fields = array_flip(array_diff(drupal_schema_fields_sql($this->entityInfo['revision_table']), drupal_schema_fields_sql($this->entityInfo['base_table'])));
+        $data_fields = array_flip(array_diff(drupal_schema_fields_sql($this->entityInfo['revision_table']), drupal_schema_fields_sql($this->entityInfo['baseTable'])));
       }
       else {
         $data_fields = array_flip(drupal_schema_fields_sql($this->entityInfo['data_table']));
@@ -352,7 +352,7 @@ public function save(EntityInterface $entity) {
 
       if (!$entity->isNew()) {
         if ($entity->isDefaultRevision()) {
-          $return = drupal_write_record($this->entityInfo['base_table'], $record, $this->idKey);
+          $return = drupal_write_record($this->entityInfo['baseTable'], $record, $this->idKey);
         }
         else {
           // @todo, should a different value be returned when saving an entity
@@ -375,7 +375,7 @@ public function save(EntityInterface $entity) {
         }
       }
       else {
-        $return = drupal_write_record($this->entityInfo['base_table'], $record);
+        $return = drupal_write_record($this->entityInfo['baseTable'], $record);
         $entity->{$this->idKey}->value = $record->{$this->idKey};
         if ($this->revisionKey) {
           $record->{$this->revisionKey} = $this->saveRevision($entity);
@@ -447,7 +447,7 @@ protected function saveRevision(EntityInterface $entity) {
       if ($entity->isNewRevision()) {
         drupal_write_record($this->revisionTable, $record);
         if ($entity->isDefaultRevision()) {
-          $this->database->update($this->entityInfo['base_table'])
+          $this->database->update($this->entityInfo['baseTable'])
             ->fields(array($this->revisionKey => $record->{$this->revisionKey}))
             ->condition($this->idKey, $record->{$this->idKey})
             ->execute();
@@ -503,7 +503,7 @@ protected function savePropertyData(EntityInterface $entity) {
    */
   protected function mapToStorageRecord(EntityInterface $entity) {
     $record = new \stdClass();
-    foreach (drupal_schema_fields_sql($this->entityInfo['base_table']) as $name) {
+    foreach (drupal_schema_fields_sql($this->entityInfo['baseTable']) as $name) {
       $record->$name = $entity->$name->value;
     }
     return $record;
@@ -584,7 +584,7 @@ public function delete(array $entities) {
       }
       $ids = array_keys($entities);
 
-      $this->database->delete($this->entityInfo['base_table'])
+      $this->database->delete($this->entityInfo['baseTable'])
         ->condition($this->idKey, $ids)
         ->execute();
 
diff --git a/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php b/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
index e72a586..2b303d9 100644
--- a/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
+++ b/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
@@ -68,7 +68,7 @@ public function addField($field, $type, $langcode) {
     // while the third will be 'node_reference.nid.tags'.
     $index_prefix = '';
     $specifiers = explode('.', $field);
-    $base_table = 'base_table';
+    $base_table = 'baseTable';
     $count = count($specifiers) - 1;
     // This will contain the definitions of the last specifier seen by the
     // system.
@@ -175,7 +175,7 @@ public function addField($field, $type, $langcode) {
           $this->sqlQuery->addMetaData('simple_query', FALSE);
           $entity_tables[$entity_info['data_table']] = drupal_get_schema($entity_info['data_table']);
         }
-        $entity_tables[$entity_info['base_table']] = drupal_get_schema($entity_info['base_table']);
+        $entity_tables[$entity_info['baseTable']] = drupal_get_schema($entity_info['baseTable']);
         $sql_column = $specifier;
         $table = $this->ensureEntityTable($index_prefix, $specifier, $type, $langcode, $base_table, $entity_id_field, $entity_tables);
       }
@@ -208,7 +208,7 @@ public function addField($field, $type, $langcode) {
           $entity_info = $entity_manager->getDefinition($entity_type);
           // Add the new entity base table using the table and sql column.
           $join_condition= '%alias.' . $entity_info['entity_keys']['id'] . " = $table.$sql_column";
-          $base_table = $this->sqlQuery->leftJoin($entity_info['base_table'], NULL, $join_condition);
+          $base_table = $this->sqlQuery->leftJoin($entity_info['baseTable'], NULL, $join_condition);
           $propertyDefinitions = array();
           $key++;
           $index_prefix .= "$next_index_prefix.";
diff --git a/core/modules/aggregator/lib/Drupal/aggregator/Entity/Feed.php b/core/modules/aggregator/lib/Drupal/aggregator/Entity/Feed.php
index 610d474..88da16e 100644
--- a/core/modules/aggregator/lib/Drupal/aggregator/Entity/Feed.php
+++ b/core/modules/aggregator/lib/Drupal/aggregator/Entity/Feed.php
@@ -30,7 +30,7 @@
  *       "remove_items" = "Drupal\aggregator\Form\FeedItemsRemoveForm"
  *     }
  *   },
- *   base_table = "aggregator_feed",
+ *   baseTable = "aggregator_feed",
  *   fieldable = TRUE,
  *   entity_keys = {
  *     "id" = "fid",
diff --git a/core/modules/aggregator/lib/Drupal/aggregator/Entity/Item.php b/core/modules/aggregator/lib/Drupal/aggregator/Entity/Item.php
index c24ad1e..d81cf42 100644
--- a/core/modules/aggregator/lib/Drupal/aggregator/Entity/Item.php
+++ b/core/modules/aggregator/lib/Drupal/aggregator/Entity/Item.php
@@ -24,7 +24,7 @@
  *     "storage" = "Drupal\aggregator\ItemStorageController",
  *     "render" = "Drupal\aggregator\ItemRenderController"
  *   },
- *   base_table = "aggregator_item",
+ *   baseTable = "aggregator_item",
  *   fieldable = TRUE,
  *   entity_keys = {
  *     "id" = "iid",
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
index 698c39c..e6f0cf7 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
@@ -34,7 +34,7 @@
  *     },
  *     "translation" = "Drupal\custom_block\CustomBlockTranslationController"
  *   },
- *   base_table = "custom_block",
+ *   baseTable = "custom_block",
  *   revision_table = "custom_block_revision",
  *   route_base_path = "admin/structure/custom-blocks/manage/{bundle}",
  *   menu_base_path = "block/%custom_block",
diff --git a/core/modules/book/lib/Drupal/book/BookManager.php b/core/modules/book/lib/Drupal/book/BookManager.php
index 19140fa..7ab0cec 100644
--- a/core/modules/book/lib/Drupal/book/BookManager.php
+++ b/core/modules/book/lib/Drupal/book/BookManager.php
@@ -76,7 +76,7 @@ protected function loadBooks() {
       $query->orderBy('ml.weight');
       $query->orderBy('ml.link_title');
       $query->addTag('node_access');
-      $query->addMetaData('base_table', 'book');
+      $query->addMetaData('baseTable', 'book');
       $book_links = $query->execute();
 
       $nodes = $this->entityManager->getStorageController('node')->loadMultiple($nids);
diff --git a/core/modules/comment/comment.module b/core/modules/comment/comment.module
index 32404be..674bc1d 100644
--- a/core/modules/comment/comment.module
+++ b/core/modules/comment/comment.module
@@ -395,7 +395,7 @@ function comment_get_recent($number = 10) {
   $query = db_select('comment', 'c');
   $query->innerJoin('node_field_data', 'n', 'n.nid = c.nid');
   $query->addTag('node_access');
-  $query->addMetaData('base_table', 'comment');
+  $query->addMetaData('baseTable', 'comment');
   $comments = $query
     ->fields('c')
     ->condition('c.status', COMMENT_PUBLISHED)
@@ -760,7 +760,7 @@ function comment_get_thread(EntityInterface $node, $mode, $comments_per_page) {
     ->condition('c.nid', $node->id())
     ->addTag('node_access')
     ->addTag('comment_filter')
-    ->addMetaData('base_table', 'comment')
+    ->addMetaData('baseTable', 'comment')
     ->addMetaData('node', $node)
     ->limit($comments_per_page);
 
@@ -770,7 +770,7 @@ function comment_get_thread(EntityInterface $node, $mode, $comments_per_page) {
     ->condition('c.nid', $node->id())
     ->addTag('node_access')
     ->addTag('comment_filter')
-    ->addMetaData('base_table', 'comment')
+    ->addMetaData('baseTable', 'comment')
     ->addMetaData('node', $node);
 
   if (!user_access('administer comments')) {
diff --git a/core/modules/comment/lib/Drupal/comment/Entity/Comment.php b/core/modules/comment/lib/Drupal/comment/Entity/Comment.php
index 59c122b..9e14990 100644
--- a/core/modules/comment/lib/Drupal/comment/Entity/Comment.php
+++ b/core/modules/comment/lib/Drupal/comment/Entity/Comment.php
@@ -32,7 +32,7 @@
  *     },
  *     "translation" = "Drupal\comment\CommentTranslationController"
  *   },
- *   base_table = "comment",
+ *   baseTable = "comment",
  *   uri_callback = "comment_uri",
  *   fieldable = TRUE,
  *   translatable = TRUE,
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php b/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php
index fff8d59..28622c5 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/entity_reference/selection/CommentSelection.php
@@ -45,7 +45,7 @@ public function buildEntityQuery($match = NULL, $match_operator = 'CONTAINS') {
    */
   public function entityQueryAlter(SelectInterface $query) {
     $tables = $query->getTables();
-    $base_table = $tables['base_table']['alias'];
+    $base_table = $tables['baseTable']['alias'];
 
     // The Comment module doesn't implement any proper comment access,
     // and as a consequence doesn't make sure that comments cannot be viewed
diff --git a/core/modules/comment/lib/Drupal/comment/Plugin/views/wizard/Comment.php b/core/modules/comment/lib/Drupal/comment/Plugin/views/wizard/Comment.php
index 410025b..20ac4de 100644
--- a/core/modules/comment/lib/Drupal/comment/Plugin/views/wizard/Comment.php
+++ b/core/modules/comment/lib/Drupal/comment/Plugin/views/wizard/Comment.php
@@ -21,7 +21,7 @@
  * @ViewsWizard(
  *   id = "comment",
  *   module = "comment",
- *   base_table = "comment",
+ *   baseTable = "comment",
  *   title = @Translation("Comments")
  * )
  */
diff --git a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php
index 74a1a8a..e6e315c 100644
--- a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php
+++ b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/entity_reference/selection/SelectionBase.php
@@ -104,7 +104,7 @@ public static function settingsForm(FieldDefinitionInterface $field_definition)
 
     // @todo Use Entity::getPropertyDefinitions() when all entity types are
     // converted to the new Field API.
-    $fields = drupal_map_assoc(drupal_schema_fields_sql($entity_info['base_table']));
+    $fields = drupal_map_assoc(drupal_schema_fields_sql($entity_info['baseTable']));
     foreach (field_info_instances($target_type) as $bundle_instances) {
       foreach ($bundle_instances as $instance_name => $instance_info) {
         $field_info = $instance_info->getField();
@@ -307,7 +307,7 @@ protected function reAlterQuery(AlterableInterface $query, $tag, $base_table) {
     $old_metadata = $query->alterMetaData;
 
     $query->alterTags = array($tag => TRUE);
-    $query->alterMetaData['base_table'] = $base_table;
+    $query->alterMetaData['baseTable'] = $base_table;
     drupal_alter(array('query', 'query_' . $tag), $query);
 
     // Restore the tags and metadata.
diff --git a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/field/field_type/ConfigurableEntityReferenceItem.php b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/field/field_type/ConfigurableEntityReferenceItem.php
index d0b616c..7a23869 100644
--- a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/field/field_type/ConfigurableEntityReferenceItem.php
+++ b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/field/field_type/ConfigurableEntityReferenceItem.php
@@ -71,7 +71,7 @@ public static function schema(FieldInterface $field) {
     if (is_subclass_of($entity_manager->getControllerClass($field['settings']['target_type'], 'storage'), 'Drupal\Core\Entity\DatabaseStorageController')) {
       $entity_info = $entity_manager->getDefinition($field['settings']['target_type']);
 
-      $base_table = $entity_info['base_table'];
+      $base_table = $entity_info['baseTable'];
       $id_column = $entity_info['entity_keys']['id'];
 
       $schema['foreign keys'][$base_table] = array(
diff --git a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/views/display/EntityReference.php b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/views/display/EntityReference.php
index 496b5ea..04009b8 100644
--- a/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/views/display/EntityReference.php
+++ b/core/modules/entity_reference/lib/Drupal/entity_reference/Plugin/views/display/EntityReference.php
@@ -123,7 +123,7 @@ public function query() {
 
     // Make sure the id field is included in the results.
     $id_field = $this->view->storage->get('base_field');
-    $this->id_field_alias = $this->view->query->addField($this->view->storage->get('base_table'), $id_field);
+    $this->id_field_alias = $this->view->query->addField($this->view->storage->get('baseTable'), $id_field);
 
     $options = $this->getOption('entity_reference_options');
 
diff --git a/core/modules/field/field.views.inc b/core/modules/field/field.views.inc
index 7e24b44..f016907 100644
--- a/core/modules/field/field.views.inc
+++ b/core/modules/field/field.views.inc
@@ -131,10 +131,10 @@ function field_views_field_default_views_data(FieldInterface $field) {
   $entity_manager = Drupal::entityManager();
   $entity_type = $field->entity_type;
   $entity_info = $entity_manager->getDefinition($entity_type);
-  if (!isset($entity_info['base_table'])) {
+  if (!isset($entity_info['baseTable'])) {
     return $data;
   }
-  $entity_table = $entity_info['base_table'];
+  $entity_table = $entity_info['baseTable'];
   $entity_tables = array($entity_table => $entity_type);
   $supports_revisions = !empty($entity_info['entity_keys']['revision']) && !empty($entity_info['revision_table']);
   if ($supports_revisions) {
diff --git a/core/modules/field/lib/Drupal/field/Entity/Field.php b/core/modules/field/lib/Drupal/field/Entity/Field.php
index 3421461..a0168ac 100644
--- a/core/modules/field/lib/Drupal/field/Entity/Field.php
+++ b/core/modules/field/lib/Drupal/field/Entity/Field.php
@@ -675,7 +675,7 @@ public function hasData() {
       $factory = \Drupal::service('entity.query');
       // Entity Query throws an exception if there is no base table.
       $entity_info = \Drupal::entityManager()->getDefinition($this->entity_type);
-      if (!isset($entity_info['base_table'])) {
+      if (!isset($entity_info['baseTable'])) {
         return FALSE;
       }
       $query = $factory->get($this->entity_type);
diff --git a/core/modules/file/file.views.inc b/core/modules/file/file.views.inc
index 501ce7c..51dfbf4 100644
--- a/core/modules/file/file.views.inc
+++ b/core/modules/file/file.views.inc
@@ -500,7 +500,7 @@ function file_field_views_data_views_data_alter(array &$data, FieldInterface $fi
     'entity_type' => $field['entity_type'],
     'field table' => DatabaseStorageController::_fieldTableName($field),
     'field field' => $field['field_name'] . '_target_id',
-    'base' => $entity_info['base_table'],
+    'base' => $entity_info['baseTable'],
     'base field' => $entity_info['entity_keys']['id'],
     'label' => t('!field_name', array('!field_name' => $field['field_name'])),
     'join_extra' => array(
diff --git a/core/modules/file/lib/Drupal/file/Entity/File.php b/core/modules/file/lib/Drupal/file/Entity/File.php
index 833f2db..4c7e15e 100644
--- a/core/modules/file/lib/Drupal/file/Entity/File.php
+++ b/core/modules/file/lib/Drupal/file/Entity/File.php
@@ -26,7 +26,7 @@
  *     "storage" = "Drupal\file\FileStorageController",
  *     "render" = "Drupal\Core\Entity\EntityRenderController"
  *   },
- *   base_table = "file_managed",
+ *   baseTable = "file_managed",
  *   entity_keys = {
  *     "id" = "fid",
  *     "label" = "filename",
diff --git a/core/modules/file/lib/Drupal/file/FileStorageController.php b/core/modules/file/lib/Drupal/file/FileStorageController.php
index 2f27551..12dc5cb 100644
--- a/core/modules/file/lib/Drupal/file/FileStorageController.php
+++ b/core/modules/file/lib/Drupal/file/FileStorageController.php
@@ -18,7 +18,7 @@ class FileStorageController extends DatabaseStorageControllerNG implements FileS
    * {@inheritdoc}
    */
   public function spaceUsed($uid = NULL, $status = FILE_STATUS_PERMANENT) {
-    $query = $this->database->select($this->entityInfo['base_table'], 'f')
+    $query = $this->database->select($this->entityInfo['baseTable'], 'f')
       ->condition('f.status', $status);
     $query->addExpression('SUM(f.filesize)', 'filesize');
     if (isset($uid)) {
@@ -33,7 +33,7 @@ public function spaceUsed($uid = NULL, $status = FILE_STATUS_PERMANENT) {
   public function retrieveTemporaryFiles() {
     // Use separate placeholders for the status to avoid a bug in some versions
     // of PHP. See http://drupal.org/node/352956.
-    return $this->database->query('SELECT fid FROM {' . $this->entityInfo['base_table'] . '} WHERE status <> :permanent AND timestamp < :timestamp', array(
+    return $this->database->query('SELECT fid FROM {' . $this->entityInfo['baseTable'] . '} WHERE status <> :permanent AND timestamp < :timestamp', array(
       ':permanent' => FILE_STATUS_PERMANENT,
       ':timestamp' => REQUEST_TIME - DRUPAL_MAXIMUM_TEMP_FILE_AGE
     ));
diff --git a/core/modules/file/lib/Drupal/file/Plugin/views/wizard/File.php b/core/modules/file/lib/Drupal/file/Plugin/views/wizard/File.php
index 7d8c4cd..96fdaee 100644
--- a/core/modules/file/lib/Drupal/file/Plugin/views/wizard/File.php
+++ b/core/modules/file/lib/Drupal/file/Plugin/views/wizard/File.php
@@ -17,7 +17,7 @@
  * @ViewsWizard(
  *   id = "file_managed",
  *   module = "file",
- *   base_table = "file_managed",
+ *   baseTable = "file_managed",
  *   title = @Translation("Files")
  * )
  */
diff --git a/core/modules/forum/lib/Drupal/forum/ForumManager.php b/core/modules/forum/lib/Drupal/forum/ForumManager.php
index 92c2a7c..4e0ac22 100644
--- a/core/modules/forum/lib/Drupal/forum/ForumManager.php
+++ b/core/modules/forum/lib/Drupal/forum/ForumManager.php
@@ -161,7 +161,7 @@ public function getTopics($tid) {
     $query
       ->condition('f.tid', $tid)
       ->addTag('node_access')
-      ->addMetaData('base_table', 'forum_index')
+      ->addMetaData('baseTable', 'forum_index')
       ->orderBy('f.sticky', 'DESC')
       ->orderByHeader($forum_topic_list_header)
       ->limit($forum_per_page);
@@ -170,7 +170,7 @@ public function getTopics($tid) {
     $count_query->condition('f.tid', $tid);
     $count_query->addExpression('COUNT(*)');
     $count_query->addTag('node_access');
-    $count_query->addMetaData('base_table', 'forum_index');
+    $count_query->addMetaData('baseTable', 'forum_index');
 
     $query->setCountQuery($count_query);
     $result = $query->execute();
diff --git a/core/modules/forum/lib/Drupal/forum/Plugin/Block/ActiveTopicsBlock.php b/core/modules/forum/lib/Drupal/forum/Plugin/Block/ActiveTopicsBlock.php
index 769aeb7..915d54f 100644
--- a/core/modules/forum/lib/Drupal/forum/Plugin/Block/ActiveTopicsBlock.php
+++ b/core/modules/forum/lib/Drupal/forum/Plugin/Block/ActiveTopicsBlock.php
@@ -27,7 +27,7 @@ public function build() {
     $query = db_select('forum_index', 'f')
       ->fields('f')
       ->addTag('node_access')
-      ->addMetaData('base_table', 'forum_index')
+      ->addMetaData('baseTable', 'forum_index')
       ->orderBy('f.last_comment_timestamp', 'DESC')
       ->range(0, $this->configuration['block_count']);
 
diff --git a/core/modules/forum/lib/Drupal/forum/Plugin/Block/NewTopicsBlock.php b/core/modules/forum/lib/Drupal/forum/Plugin/Block/NewTopicsBlock.php
index 44622a1..114ffad 100644
--- a/core/modules/forum/lib/Drupal/forum/Plugin/Block/NewTopicsBlock.php
+++ b/core/modules/forum/lib/Drupal/forum/Plugin/Block/NewTopicsBlock.php
@@ -27,7 +27,7 @@ public function build() {
     $query = db_select('forum_index', 'f')
       ->fields('f')
       ->addTag('node_access')
-      ->addMetaData('base_table', 'forum_index')
+      ->addMetaData('baseTable', 'forum_index')
       ->orderBy('f.created', 'DESC')
       ->range(0, $this->configuration['block_count']);
 
diff --git a/core/modules/image/image.views.inc b/core/modules/image/image.views.inc
index 356f140..558c458 100644
--- a/core/modules/image/image.views.inc
+++ b/core/modules/image/image.views.inc
@@ -54,7 +54,7 @@ function image_field_views_data_views_data_alter(array &$data, FieldInterface $f
     'entity_type' => $field['entity_type'],
     'field table' => DatabaseStorageController::_fieldTableName($field),
     'field field' => $field['field_name'] . '_target_id',
-    'base' => $entity_info['base_table'],
+    'base' => $entity_info['baseTable'],
     'base field' => $entity_info['entity_keys']['id'],
     'label' => t('!field_name', array('!field_name' => $field['field_name'])),
     'join_extra' => array(
diff --git a/core/modules/menu_link/lib/Drupal/menu_link/Entity/MenuLink.php b/core/modules/menu_link/lib/Drupal/menu_link/Entity/MenuLink.php
index d6493f5..70a9db5 100644
--- a/core/modules/menu_link/lib/Drupal/menu_link/Entity/MenuLink.php
+++ b/core/modules/menu_link/lib/Drupal/menu_link/Entity/MenuLink.php
@@ -35,7 +35,7 @@
  *     }
  *   },
  *   static_cache = FALSE,
- *   base_table = "menu_links",
+ *   baseTable = "menu_links",
  *   uri_callback = "menu_link_uri",
  *   translatable = TRUE,
  *   entity_keys = {
diff --git a/core/modules/menu_link/lib/Drupal/menu_link/MenuLinkStorageController.php b/core/modules/menu_link/lib/Drupal/menu_link/MenuLinkStorageController.php
index 7330147..c094833 100644
--- a/core/modules/menu_link/lib/Drupal/menu_link/MenuLinkStorageController.php
+++ b/core/modules/menu_link/lib/Drupal/menu_link/MenuLinkStorageController.php
@@ -163,7 +163,7 @@ public function save(EntityInterface $entity) {
       }
 
       if ($entity->isNew()) {
-        $entity->mlid = $this->database->insert($this->entityInfo['base_table'])->fields(array('menu_name' => 'tools'))->execute();
+        $entity->mlid = $this->database->insert($this->entityInfo['baseTable'])->fields(array('menu_name' => 'tools'))->execute();
         $entity->enforceIsNew();
       }
 
@@ -180,7 +180,7 @@ public function save(EntityInterface $entity) {
       // $entity may have additional keys left over from building a router entry.
       // The intersect removes the extra keys, allowing a meaningful comparison.
       if ($entity->isNew() || (array_intersect_key(get_object_vars($entity), get_object_vars($entity->original)) != get_object_vars($entity->original))) {
-        $return = drupal_write_record($this->entityInfo['base_table'], $entity, $this->idKey);
+        $return = drupal_write_record($this->entityInfo['baseTable'], $entity, $this->idKey);
 
         if ($return) {
           if (!$entity->isNew()) {
@@ -326,7 +326,7 @@ public function findChildrenRelativeDepth(EntityInterface $entity) {
    * {@inheritdoc}
    */
   public function moveChildren(EntityInterface $entity) {
-    $query = $this->database->update($this->entityInfo['base_table']);
+    $query = $this->database->update($this->entityInfo['baseTable']);
 
     $query->fields(array('menu_name' => $entity->menu_name));
 
diff --git a/core/modules/node/lib/Drupal/node/Entity/Node.php b/core/modules/node/lib/Drupal/node/Entity/Node.php
index 99063bb..14cd977 100644
--- a/core/modules/node/lib/Drupal/node/Entity/Node.php
+++ b/core/modules/node/lib/Drupal/node/Entity/Node.php
@@ -34,7 +34,7 @@
  *     },
  *     "translation" = "Drupal\node\NodeTranslationController"
  *   },
- *   base_table = "node",
+ *   baseTable = "node",
  *   data_table = "node_field_data",
  *   revision_table = "node_field_revision",
  *   uri_callback = "node_uri",
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/wizard/Node.php b/core/modules/node/lib/Drupal/node/Plugin/views/wizard/Node.php
index 29e6a46..7cebdf8 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/wizard/Node.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/wizard/Node.php
@@ -21,7 +21,7 @@
  * @ViewsWizard(
  *   id = "node",
  *   module = "node",
- *   base_table = "node",
+ *   baseTable = "node",
  *   title = @Translation("Content")
  * )
  */
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/wizard/NodeRevision.php b/core/modules/node/lib/Drupal/node/Plugin/views/wizard/NodeRevision.php
index 1d73184..5fffdca 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/wizard/NodeRevision.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/wizard/NodeRevision.php
@@ -21,7 +21,7 @@
  * @ViewsWizard(
  *   id = "node_revision",
  *   module = "node",
- *   base_table = "node_field_revision",
+ *   baseTable = "node_field_revision",
  *   title = @Translation("Content revisions")
  * )
  */
diff --git a/core/modules/node/node.module b/core/modules/node/node.module
index 6d3708d..2bf21d1 100644
--- a/core/modules/node/node.module
+++ b/core/modules/node/node.module
@@ -2200,7 +2200,7 @@ function node_access_view_all_nodes($account = NULL) {
  * @code
  *   $query
  *     ->addTag('node_access')
- *     ->addMetaData('base_table', 'taxonomy_index');
+ *     ->addMetaData('baseTable', 'taxonomy_index');
  * @endcode
  */
 function node_query_node_access_alter(AlterableInterface $query) {
@@ -2228,7 +2228,7 @@ function node_query_node_access_alter(AlterableInterface $query) {
   }
 
   $tables = $query->getTables();
-  $base_table = $query->getMetaData('base_table');
+  $base_table = $query->getMetaData('baseTable');
   // If the base table is not given, default to node if present.
   if (!$base_table) {
     foreach ($tables as $table_info) {
@@ -2243,7 +2243,7 @@ function node_query_node_access_alter(AlterableInterface $query) {
     }
     // Bail out if the base table is missing.
     if (!$base_table) {
-      throw new Exception(t('Query tagged for node access but there is no node table, specify the base_table using meta data.'));
+      throw new Exception(t('Query tagged for node access but there is no node table, specify the baseTable using meta data.'));
     }
   }
 
diff --git a/core/modules/node/node.views_execution.inc b/core/modules/node/node.views_execution.inc
index e43690b..d1c476d 100644
--- a/core/modules/node/node.views_execution.inc
+++ b/core/modules/node/node.views_execution.inc
@@ -24,7 +24,7 @@ function node_views_query_substitutions(ViewExecutable $view) {
 function node_views_analyze(ViewExecutable $view) {
   $ret = array();
   // Check for something other than the default display:
-  if ($view->storage->get('base_table') == 'node') {
+  if ($view->storage->get('baseTable') == 'node') {
     foreach ($view->displayHandlers as $id => $display) {
       if (!$display->isDefaulted('access') || !$display->isDefaulted('filters')) {
         // check for no access control
diff --git a/core/modules/search/lib/Drupal/search/Plugin/views/argument/Search.php b/core/modules/search/lib/Drupal/search/Plugin/views/argument/Search.php
index 96810a6..c8a0c42 100644
--- a/core/modules/search/lib/Drupal/search/Plugin/views/argument/Search.php
+++ b/core/modules/search/lib/Drupal/search/Plugin/views/argument/Search.php
@@ -71,7 +71,7 @@ public function query($group_by = FALSE) {
       $this->search_score = $this->query->addField('', "SUM($search_index.score * $search_total.count)", 'score', array('aggregate' => TRUE));
 
       if (empty($this->query->relationships[$this->relationship])) {
-        $base_table = $this->view->storage->get('base_table');
+        $base_table = $this->view->storage->get('baseTable');
       }
       else {
         $base_table = $this->query->relationships[$this->relationship]['base'];
diff --git a/core/modules/search/lib/Drupal/search/Plugin/views/filter/Search.php b/core/modules/search/lib/Drupal/search/Plugin/views/filter/Search.php
index 89b21e4..8c697de 100644
--- a/core/modules/search/lib/Drupal/search/Plugin/views/filter/Search.php
+++ b/core/modules/search/lib/Drupal/search/Plugin/views/filter/Search.php
@@ -152,7 +152,7 @@ public function query() {
       $this->search_score = $this->query->addField('', "SUM($search_index.score * $search_total.count)", 'score', array('aggregate' => TRUE));
 
       if (empty($this->query->relationships[$this->relationship])) {
-        $base_table = $this->view->storage->get('base_table');
+        $base_table = $this->view->storage->get('baseTable');
       }
       else {
         $base_table = $this->query->relationships[$this->relationship]['base'];
diff --git a/core/modules/system/lib/Drupal/system/Tests/Module/ModuleTestBase.php b/core/modules/system/lib/Drupal/system/Tests/Module/ModuleTestBase.php
index 95844f6..34dbf10 100644
--- a/core/modules/system/lib/Drupal/system/Tests/Module/ModuleTestBase.php
+++ b/core/modules/system/lib/Drupal/system/Tests/Module/ModuleTestBase.php
@@ -45,9 +45,9 @@ function assertTableCount($base_table, $count = TRUE) {
     $tables = db_find_tables(Database::getConnection()->prefixTables('{' . $base_table . '}') . '%');
 
     if ($count) {
-      return $this->assertTrue($tables, format_string('Tables matching "@base_table" found.', array('@base_table' => $base_table)));
+      return $this->assertTrue($tables, format_string('Tables matching "@baseTable" found.', array('@baseTable' => $base_table)));
     }
-    return $this->assertFalse($tables, format_string('Tables matching "@base_table" not found.', array('@base_table' => $base_table)));
+    return $this->assertFalse($tables, format_string('Tables matching "@baseTable" not found.', array('@baseTable' => $base_table)));
   }
 
   /**
diff --git a/core/modules/system/system.api.php b/core/modules/system/system.api.php
index 49e87a0..d0d5923 100644
--- a/core/modules/system/system.api.php
+++ b/core/modules/system/system.api.php
@@ -3672,7 +3672,7 @@ function hook_link_alter(&$variables) {
  * *   id = "comment",
  * *   label = @Translation("Comment"),
  * *   ...
- * *   base_table = "comment"
+ * *   baseTable = "comment"
  * * )
  * @endcode
  *
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
index 95d74ce..86e67c6 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
@@ -28,7 +28,7 @@
  *     },
  *     "translation" = "Drupal\content_translation\ContentTranslationControllerNG"
  *   },
- *   base_table = "entity_test",
+ *   baseTable = "entity_test",
  *   fieldable = TRUE,
  *   field_cache = FALSE,
  *   entity_keys = {
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestCache.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestCache.php
index b4a064f..226fea5 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestCache.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestCache.php
@@ -26,7 +26,7 @@
  *     },
  *     "translation" = "Drupal\content_translation\ContentTranslationControllerNG"
  *   },
- *   base_table = "entity_test",
+ *   baseTable = "entity_test",
  *   fieldable = TRUE,
  *   field_cache = TRUE,
  *   entity_keys = {
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestDefaultAccess.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestDefaultAccess.php
index 4893c83..5873733 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestDefaultAccess.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestDefaultAccess.php
@@ -20,7 +20,7 @@
  *   controllers = {
  *     "storage" = "Drupal\entity_test\EntityTestStorageController"
  *   },
- *   base_table = "entity_test",
+ *   baseTable = "entity_test",
  *   entity_keys = {
  *     "id" = "id",
  *     "bundle" = "type"
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabel.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabel.php
index 224da5a..728f079 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabel.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabel.php
@@ -20,7 +20,7 @@
  *   controllers = {
  *     "storage" = "Drupal\entity_test\EntityTestStorageController"
  *   },
- *   base_table = "entity_test",
+ *   baseTable = "entity_test",
  *   entity_keys = {
  *     "id" = "id",
  *     "label" = "name",
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabelCallback.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabelCallback.php
index 1784aa2..1ec34b0 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabelCallback.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestLabelCallback.php
@@ -21,7 +21,7 @@
  *     "storage" = "Drupal\entity_test\EntityTestStorageController"
  *   },
  *   field_cache = FALSE,
- *   base_table = "entity_test",
+ *   baseTable = "entity_test",
  *   revision_table = "entity_test_revision",
  *   label_callback = "entity_test_label_callback",
  *   fieldable = TRUE,
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMul.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMul.php
index 3f7e833..8a54597 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMul.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMul.php
@@ -26,7 +26,7 @@
  *     },
  *     "translation" = "Drupal\content_translation\ContentTranslationControllerNG"
  *   },
- *   base_table = "entity_test_mul",
+ *   baseTable = "entity_test_mul",
  *   data_table = "entity_test_mul_property_data",
  *   fieldable = TRUE,
  *   translatable = TRUE,
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMulRev.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMulRev.php
index 4a578e2..9ec09d6 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMulRev.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestMulRev.php
@@ -26,7 +26,7 @@
  *     },
  *     "translation" = "Drupal\content_translation\ContentTranslationControllerNG"
  *   },
- *   base_table = "entity_test_mulrev",
+ *   baseTable = "entity_test_mulrev",
  *   data_table = "entity_test_mulrev_property_data",
  *   revision_table = "entity_test_mulrev_property_revision",
  *   fieldable = TRUE,
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestNoLabel.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestNoLabel.php
index f56a5e0..d5be67c 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestNoLabel.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestNoLabel.php
@@ -21,7 +21,7 @@
  *     "storage" = "Drupal\entity_test\EntityTestStorageController"
  *   },
  *   field_cache = FALSE,
- *   base_table = "entity_test",
+ *   baseTable = "entity_test",
  *   entity_keys = {
  *     "id" = "id",
  *     "bundle" = "type"
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRender.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRender.php
index 3c0869d..11bacd5 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRender.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRender.php
@@ -21,7 +21,7 @@
  *     "storage" = "Drupal\entity_test\EntityTestStorageController",
  *     "render" = "Drupal\entity_test\EntityTestRenderController"
  *   },
- *   base_table = "entity_test",
+ *   baseTable = "entity_test",
  *   fieldable = TRUE,
  *   entity_keys = {
  *     "id" = "id",
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRev.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRev.php
index 0fabcca..08be5a6 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRev.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTestRev.php
@@ -26,7 +26,7 @@
  *     },
  *     "translation" = "Drupal\content_translation\ContentTranslationControllerNG"
  *   },
- *   base_table = "entity_test_rev",
+ *   baseTable = "entity_test_rev",
  *   revision_table = "entity_test_rev_revision",
  *   fieldable = TRUE,
  *   entity_keys = {
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Term.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Term.php
index daeb3ac..69740fc 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Term.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Term.php
@@ -32,7 +32,7 @@
  *     },
  *     "translation" = "Drupal\taxonomy\TermTranslationController"
  *   },
- *   base_table = "taxonomy_term_data",
+ *   baseTable = "taxonomy_term_data",
  *   uri_callback = "taxonomy_term_uri",
  *   fieldable = TRUE,
  *   translatable = TRUE,
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/filter/TaxonomyIndexTidDepth.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/filter/TaxonomyIndexTidDepth.php
index 3bae73d..172bde1 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/filter/TaxonomyIndexTidDepth.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/filter/TaxonomyIndexTidDepth.php
@@ -70,8 +70,8 @@ public function query() {
       $this->tableAlias = $this->relationship;
     }
     // If no relationship, then use the alias of the base table.
-    elseif (isset($this->query->table_queue[$this->view->storage->get('base_table')]['alias'])) {
-      $this->tableAlias = $this->query->table_queue[$this->view->storage->get('base_table')]['alias'];
+    elseif (isset($this->query->table_queue[$this->view->storage->get('baseTable')]['alias'])) {
+      $this->tableAlias = $this->query->table_queue[$this->view->storage->get('baseTable')]['alias'];
     }
     // This should never happen, but if it does, we fail quietly.
     else {
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/wizard/TaxonomyTerm.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/wizard/TaxonomyTerm.php
index d9409ae..1aaf44a 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/wizard/TaxonomyTerm.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/wizard/TaxonomyTerm.php
@@ -17,7 +17,7 @@
  * @ViewsWizard(
  *   id = "taxonomy_term",
  *   module = "taxonomy",
- *   base_table = "taxonomy_term_data",
+ *   baseTable = "taxonomy_term_data",
  *   title = @Translation("Taxonomy terms")
  * )
  */
diff --git a/core/modules/taxonomy/taxonomy.module b/core/modules/taxonomy/taxonomy.module
index 5769da0..a8f434b 100644
--- a/core/modules/taxonomy/taxonomy.module
+++ b/core/modules/taxonomy/taxonomy.module
@@ -187,7 +187,7 @@ function taxonomy_select_nodes($tid, $pager = TRUE, $limit = FALSE, $order = arr
   }
   $query = db_select('taxonomy_index', 't');
   $query->addTag('node_access');
-  $query->addMetaData('base_table', 'taxonomy_index');
+  $query->addMetaData('baseTable', 'taxonomy_index');
   $query->condition('tid', $tid);
   if ($pager) {
     $count_query = clone $query;
diff --git a/core/modules/taxonomy/taxonomy.views.inc b/core/modules/taxonomy/taxonomy.views.inc
index 9b37e9e..ee80eb5 100644
--- a/core/modules/taxonomy/taxonomy.views.inc
+++ b/core/modules/taxonomy/taxonomy.views.inc
@@ -382,7 +382,7 @@ function taxonomy_field_views_data_views_data_alter(array &$data, FieldInterface
     'entity_type' => $field['entity_type'],
     'field table' => DatabaseStorageController::_fieldTableName($field),
     'field field' => $field['field_name'] . '_target_id',
-    'base' => $entity_info['base_table'],
+    'base' => $entity_info['baseTable'],
     'base field' => $entity_info['entity_keys']['id'],
     'label' => t('!field_name', array('!field_name' => $field['field_name'])),
     'join_extra' => array(
diff --git a/core/modules/tracker/tracker.pages.inc b/core/modules/tracker/tracker.pages.inc
index 8e187ef..90174d2 100644
--- a/core/modules/tracker/tracker.pages.inc
+++ b/core/modules/tracker/tracker.pages.inc
@@ -21,7 +21,7 @@ function tracker_page($account = NULL, $set_title = FALSE) {
   if ($account) {
     $query = db_select('tracker_user', 't')
       ->extend('Drupal\Core\Database\Query\PagerSelectExtender')
-      ->addMetaData('base_table', 'tracker_user')
+      ->addMetaData('baseTable', 'tracker_user')
       ->condition('t.uid', $account->id());
 
     if ($set_title) {
@@ -34,7 +34,7 @@ function tracker_page($account = NULL, $set_title = FALSE) {
   else {
     $query = db_select('tracker_node', 't', array('target' => 'slave'))
       ->extend('Drupal\Core\Database\Query\PagerSelectExtender')
-      ->addMetaData('base_table', 'tracker_node');
+      ->addMetaData('baseTable', 'tracker_node');
   }
 
   // This array acts as a placeholder for the data selected later
diff --git a/core/modules/user/lib/Drupal/user/Entity/User.php b/core/modules/user/lib/Drupal/user/Entity/User.php
index 21accca..4982052 100644
--- a/core/modules/user/lib/Drupal/user/Entity/User.php
+++ b/core/modules/user/lib/Drupal/user/Entity/User.php
@@ -31,7 +31,7 @@
  *     },
  *     "translation" = "Drupal\user\ProfileTranslationController"
  *   },
- *   base_table = "users",
+ *   baseTable = "users",
  *   uri_callback = "user_uri",
  *   route_base_path = "admin/config/people/accounts",
  *   label_callback = "user_label",
diff --git a/core/modules/user/lib/Drupal/user/Plugin/entity_reference/selection/UserSelection.php b/core/modules/user/lib/Drupal/user/Plugin/entity_reference/selection/UserSelection.php
index 92a8dd5..0fadac4 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/entity_reference/selection/UserSelection.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/entity_reference/selection/UserSelection.php
@@ -139,7 +139,7 @@ public function entityQueryAlter(SelectInterface $query) {
       $filter_settings = $this->instance['settings']['handler_settings']['filter'];
       if ($filter_settings['type'] == 'role') {
         $tables = $query->getTables();
-        $base_table = $tables['base_table']['alias'];
+        $base_table = $tables['baseTable']['alias'];
         $query->join('users_roles', 'ur', $base_table . '.uid = ur.uid');
         $query->condition('ur.rid', $filter_settings['role']);
       }
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/wizard/Users.php b/core/modules/user/lib/Drupal/user/Plugin/views/wizard/Users.php
index f0121c9..6017f50 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/views/wizard/Users.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/views/wizard/Users.php
@@ -21,7 +21,7 @@
  * @ViewsWizard(
  *   id = "users",
  *   module = "user",
- *   base_table = "users",
+ *   baseTable = "users",
  *   title = @Translation("Users")
  * )
  */
diff --git a/core/modules/views/lib/Drupal/views/Entity/View.php b/core/modules/views/lib/Drupal/views/Entity/View.php
index e98ae01..4bb9ed4 100644
--- a/core/modules/views/lib/Drupal/views/Entity/View.php
+++ b/core/modules/views/lib/Drupal/views/Entity/View.php
@@ -299,7 +299,7 @@ public function &getDisplay($display_id) {
   public function getExportProperties() {
     $names = array(
       'base_field',
-      'base_table',
+      'baseTable',
       'core',
       'description',
       'status',
diff --git a/core/modules/views/lib/Drupal/views/ManyToOneHelper.php b/core/modules/views/lib/Drupal/views/ManyToOneHelper.php
index 08c8cd9..4c250f6 100644
--- a/core/modules/views/lib/Drupal/views/ManyToOneHelper.php
+++ b/core/modules/views/lib/Drupal/views/ManyToOneHelper.php
@@ -79,7 +79,7 @@ public function addTable($join = NULL, $alias = NULL) {
 
     // Determine the primary table to seek
     if (empty($this->handler->query->relationships[$relationship])) {
-      $base_table = $this->handler->view->storage->get('base_table');
+      $base_table = $this->handler->view->storage->get('baseTable');
     }
     else {
       $base_table = $this->handler->query->relationships[$relationship]['base'];
diff --git a/core/modules/views/lib/Drupal/views/Plugin/Derivative/DefaultWizardDeriver.php b/core/modules/views/lib/Drupal/views/Plugin/Derivative/DefaultWizardDeriver.php
index a46bbd8..8bdab4b 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/Derivative/DefaultWizardDeriver.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/Derivative/DefaultWizardDeriver.php
@@ -28,7 +28,7 @@ public function getDerivativeDefinitions(array $base_plugin_definition) {
       if (empty($views_info['table']['wizard_id'])) {
         $this->derivatives[$table] = array(
           'id' => 'standard',
-          'base_table' => $table,
+          'baseTable' => $table,
           'title' => $views_info['table']['base']['title'],
           'class' => 'Drupal\views\Plugin\views\wizard\Standard'
         );
diff --git a/core/modules/views/lib/Drupal/views/Plugin/Derivative/ViewsEntityRow.php b/core/modules/views/lib/Drupal/views/Plugin/Derivative/ViewsEntityRow.php
index 252568d..19acd9b 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/Derivative/ViewsEntityRow.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/Derivative/ViewsEntityRow.php
@@ -93,13 +93,13 @@ public function getDerivativeDefinition($derivative_id, array $base_plugin_defin
   public function getDerivativeDefinitions(array $base_plugin_definition) {
     foreach ($this->entityManager->getDefinitions() as $entity_type => $entity_info) {
       // Just add support for entity types which have a views integration.
-      if (isset($entity_info['base_table']) && $this->viewsData->get($entity_info['base_table']) && $this->entityManager->hasController($entity_type, 'render')) {
+      if (isset($entity_info['baseTable']) && $this->viewsData->get($entity_info['baseTable']) && $this->entityManager->hasController($entity_type, 'render')) {
         $this->derivatives[$entity_type] = array(
           'id' => 'entity:' . $entity_type,
           'module' => 'views',
           'title' => $entity_info['label'],
           'help' => t('Display the @label', array('@label' => $entity_info['label'])),
-          'base' => array($entity_info['base_table']),
+          'base' => array($entity_info['baseTable']),
           'entity_type' => $entity_type,
           'display_types' => array('normal'),
           'class' => $base_plugin_definition['class'],
diff --git a/core/modules/views/lib/Drupal/views/Plugin/entity_reference/selection/ViewsSelection.php b/core/modules/views/lib/Drupal/views/Plugin/entity_reference/selection/ViewsSelection.php
index 5a7dba5..f20b9ef 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/entity_reference/selection/ViewsSelection.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/entity_reference/selection/ViewsSelection.php
@@ -68,7 +68,7 @@ public static function settingsForm(FieldDefinitionInterface $field_definition)
     $options = array();
     foreach ($displays as $data) {
       list($view, $display_id) = $data;
-      if ($view->storage->get('base_table') == $entity_info['base_table']) {
+      if ($view->storage->get('baseTable') == $entity_info['baseTable']) {
         $name = $view->storage->get('id');
         $display = $view->storage->get('display');
         $options[$name . ':' . $display_id] = $name . ' - ' . $display[$display_id]['display_title'];
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/HandlerBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/HandlerBase.php
index 51d3a99..f05c3e3 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/HandlerBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/HandlerBase.php
@@ -591,7 +591,7 @@ public function getJoin() {
     // get the join from this table that links back to the base table.
     // Determine the primary table to seek
     if (empty($this->query->relationships[$this->relationship])) {
-      $base_table = $this->view->storage->get('base_table');
+      $base_table = $this->view->storage->get('baseTable');
     }
     else {
       $base_table = $this->query->relationships[$this->relationship]['base'];
@@ -704,7 +704,7 @@ public function getEntityType() {
       $views_data = Views::viewsData()->get($this->view->relationship->table);
     }
     else {
-      $views_data = Views::viewsData()->get($this->view->storage->get('base_table'));
+      $views_data = Views::viewsData()->get($this->view->storage->get('baseTable'));
     }
 
     if (isset($views_data['table']['entity type'])) {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php
index 862a847..f63dd08 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php
@@ -855,7 +855,7 @@ public function summaryBasics($count_field = TRUE) {
     // Add the number of nodes counter
     $distinct = ($this->view->display_handler->getOption('distinct') && empty($this->query->no_distinct));
 
-    $count_alias = $this->query->addField($this->view->storage->get('base_table'), $this->view->storage->get('base_field'), 'num_records', array('count' => TRUE, 'distinct' => $distinct));
+    $count_alias = $this->query->addField($this->view->storage->get('baseTable'), $this->view->storage->get('base_field'), 'num_records', array('count' => TRUE, 'distinct' => $distinct));
     $this->query->addGroupBy($this->name_alias);
 
     if ($count_field) {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
index b09320c..390d009 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
@@ -834,7 +834,7 @@ public function getPlugin($type) {
 
     // Query plugins allow specifying a specific query class per base table.
     if ($type == 'query') {
-      $views_data = Views::viewsData()->get($this->view->storage->get('base_table'));
+      $views_data = Views::viewsData()->get($this->view->storage->get('baseTable'));
       $name = isset($views_data['table']['base']['query_id']) ? $views_data['table']['base']['query_id'] : 'views_query';
     }
     else {
@@ -1501,7 +1501,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $access = $this->getOption('access');
         $form['access']['type'] =  array(
           '#type' => 'radios',
-          '#options' => views_fetch_plugin_names('access', $this->getType(), array($this->view->storage->get('base_table'))),
+          '#options' => views_fetch_plugin_names('access', $this->getType(), array($this->view->storage->get('baseTable'))),
           '#default_value' => $access['type'],
         );
 
@@ -1536,7 +1536,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $cache = $this->getOption('cache');
         $form['cache']['type'] =  array(
           '#type' => 'radios',
-          '#options' => views_fetch_plugin_names('cache', $this->getType(), array($this->view->storage->get('base_table'))),
+          '#options' => views_fetch_plugin_names('cache', $this->getType(), array($this->view->storage->get('baseTable'))),
           '#default_value' => $cache['type'],
         );
 
@@ -1587,7 +1587,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $entity_tables = array();
         $has_translation_handlers = FALSE;
         foreach ($entities as $type => $entity_info) {
-          $entity_tables[] = $entity_info['base_table'];
+          $entity_tables[] = $entity_info['baseTable'];
 
           if (!empty($entity_info['translation'])) {
             $has_translation_handlers = TRUE;
@@ -1597,7 +1597,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         // Doesn't make sense to show a field setting here if we aren't querying
         // an entity base table. Also, we make sure that there's at least one
         // entity type with a translation handler attached.
-        if (in_array($this->view->storage->get('base_table'), $entity_tables) && $has_translation_handlers) {
+        if (in_array($this->view->storage->get('baseTable'), $entity_tables) && $has_translation_handlers) {
           $languages = array(
             '***CURRENT_LANGUAGE***' => t("Current user's language"),
             '***DEFAULT_LANGUAGE***' => t("Default site language"),
@@ -1627,7 +1627,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $style_plugin = $this->getPlugin('style');
         $form['style'] =  array(
           '#type' => 'radios',
-          '#options' => views_fetch_plugin_names('style', $this->getType(), array($this->view->storage->get('base_table'))),
+          '#options' => views_fetch_plugin_names('style', $this->getType(), array($this->view->storage->get('baseTable'))),
           '#default_value' => $style_plugin->definition['id'],
           '#description' => t('If the style you choose has settings, be sure to click the settings button that will appear next to it in the View summary.'),
         );
@@ -1669,7 +1669,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $row_plugin_instance = $this->getPlugin('row');
         $form['row'] =  array(
           '#type' => 'radios',
-          '#options' => views_fetch_plugin_names('row', $this->getType(), array($this->view->storage->get('base_table'))),
+          '#options' => views_fetch_plugin_names('row', $this->getType(), array($this->view->storage->get('baseTable'))),
           '#default_value' => $row_plugin_instance->definition['id'],
         );
 
@@ -1988,7 +1988,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $exposed_form = $this->getOption('exposed_form');
         $form['exposed_form']['type'] =  array(
           '#type' => 'radios',
-          '#options' => views_fetch_plugin_names('exposed_form', $this->getType(), array($this->view->storage->get('base_table'))),
+          '#options' => views_fetch_plugin_names('exposed_form', $this->getType(), array($this->view->storage->get('baseTable'))),
           '#default_value' => $exposed_form['type'],
         );
 
@@ -2022,7 +2022,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $pager = $this->getOption('pager');
         $form['pager']['type'] =  array(
           '#type' => 'radios',
-          '#options' => views_fetch_plugin_names('pager', !$this->usesPager() ? 'basic' : NULL, array($this->view->storage->get('base_table'))),
+          '#options' => views_fetch_plugin_names('pager', !$this->usesPager() ? 'basic' : NULL, array($this->view->storage->get('baseTable'))),
           '#default_value' => $pager['type'],
         );
 
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php b/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php
index 8d61458..8ecd16e 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/display/Feed.php
@@ -51,7 +51,7 @@ public function initDisplay(ViewExecutable $view, array &$display, array &$optio
     // Set the default row style. Ideally this would be part of the option
     // definition, but in this case it's dependent on the view's base table,
     // which we don't know until init().
-    $row_plugins = views_fetch_plugin_names('row', $this->getType(), array($view->storage->get('base_table')));
+    $row_plugins = views_fetch_plugin_names('row', $this->getType(), array($view->storage->get('baseTable')));
     $default_row_plugin = key($row_plugins);
     if (empty($this->options['row']['type'])) {
       $this->options['row']['type'] = $default_row_plugin;
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php b/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php
index c70c466..8df4082 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php
@@ -114,7 +114,7 @@ class Sql extends QueryPluginBase {
   public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
     parent::init($view, $display, $options);
 
-    $base_table = $this->view->storage->get('base_table');
+    $base_table = $this->view->storage->get('baseTable');
     $base_field = $this->view->storage->get('base_field');
     $this->relationships[$base_table] = array(
       'link' => NULL,
@@ -277,7 +277,7 @@ public function submitOptionsForm(&$form, &$form_state) {
    */
   public function addRelationship($alias, JoinPluginBase $join, $base, $link_point = NULL) {
     if (empty($link_point)) {
-      $link_point = $this->view->storage->get('base_table');
+      $link_point = $this->view->storage->get('baseTable');
     }
     elseif (!array_key_exists($link_point, $this->relationships)) {
       return FALSE;
@@ -311,7 +311,7 @@ public function addRelationship($alias, JoinPluginBase $join, $base, $link_point
       'base' => $base,
     );
 
-    $this->tables[$this->view->storage->get('base_table')][$alias] = array(
+    $this->tables[$this->view->storage->get('baseTable')][$alias] = array(
       'count' => 1,
       'alias' => $alias,
     );
@@ -395,7 +395,7 @@ public function queueTable($table, $relationship = NULL, JoinPluginBase $join =
     }
 
     if (empty($relationship)) {
-      $relationship = $this->view->storage->get('base_table');
+      $relationship = $this->view->storage->get('baseTable');
     }
 
     if (!array_key_exists($relationship, $this->relationships)) {
@@ -403,7 +403,7 @@ public function queueTable($table, $relationship = NULL, JoinPluginBase $join =
     }
 
     if (!$alias && $join && $relationship && !empty($join->adjusted) && $table != $join->table) {
-      if ($relationship == $this->view->storage->get('base_table')) {
+      if ($relationship == $this->view->storage->get('baseTable')) {
         $alias = $table;
       }
       else {
@@ -427,7 +427,7 @@ public function queueTable($table, $relationship = NULL, JoinPluginBase $join =
     // If this is a relationship based table, add a marker with
     // the relationship as a primary table for the alias.
     if ($table != $alias) {
-      $this->markTable($alias, $this->view->storage->get('base_table'), $alias);
+      $this->markTable($alias, $this->view->storage->get('baseTable'), $alias);
     }
 
     // If no join is specified, pull it from the table data.
@@ -456,7 +456,7 @@ protected function markTable($table, $relationship, $alias) {
     if (empty($this->tables[$relationship][$table])) {
       if (!isset($alias)) {
         $alias = '';
-        if ($relationship != $this->view->storage->get('base_table')) {
+        if ($relationship != $this->view->storage->get('baseTable')) {
           // double underscore will help prevent accidental name
           // space collisions.
           $alias = $relationship . '__';
@@ -496,14 +496,14 @@ protected function markTable($table, $relationship, $alias) {
   public function ensureTable($table, $relationship = NULL, JoinPluginBase $join = NULL) {
     // ensure a relationship
     if (empty($relationship)) {
-      $relationship = $this->view->storage->get('base_table');
+      $relationship = $this->view->storage->get('baseTable');
     }
 
     // If the relationship is the primary table, this actually be a relationship
     // link back from an alias. We store all aliases along with the primary table
     // to detect this state, because eventually it'll hit a table we already
     // have and that's when we want to stop.
-    if ($relationship == $this->view->storage->get('base_table') && !empty($this->tables[$relationship][$table])) {
+    if ($relationship == $this->view->storage->get('baseTable') && !empty($this->tables[$relationship][$table])) {
       return $this->tables[$relationship][$table]['alias'];
     }
 
@@ -574,7 +574,7 @@ public function ensureTable($table, $relationship = NULL, JoinPluginBase $join =
    */
   protected function ensurePath($table, $relationship = NULL, $join = NULL, $traced = array(), $add = array()) {
     if (!isset($relationship)) {
-      $relationship = $this->view->storage->get('base_table');
+      $relationship = $this->view->storage->get('baseTable');
     }
 
     if (!array_key_exists($relationship, $this->relationships)) {
@@ -634,7 +634,7 @@ protected function adjustJoin($join, $relationship) {
     }
 
     // Adjusts the left table for our relationship.
-    if ($relationship != $this->view->storage->get('base_table')) {
+    if ($relationship != $this->view->storage->get('baseTable')) {
       // If we're linking to the primary table, the relationship to use will
       // be the prior relationship. Unless it's a direct link.
 
@@ -698,8 +698,8 @@ public function getTableInfo($table) {
     }
 
     // In rare cases we might *only* have aliased versions of the table.
-    if (!empty($this->tables[$this->view->storage->get('base_table')][$table])) {
-      $alias = $this->tables[$this->view->storage->get('base_table')][$table]['alias'];
+    if (!empty($this->tables[$this->view->storage->get('baseTable')][$table])) {
+      $alias = $this->tables[$this->view->storage->get('baseTable')][$table]['alias'];
       if (!empty($this->table_queue[$alias])) {
         return $this->table_queue[$alias];
       }
@@ -730,7 +730,7 @@ public function getTableInfo($table) {
    */
   public function addField($table, $field, $alias = '', $params = array()) {
     // We check for this specifically because it gets a special alias.
-    if ($table == $this->view->storage->get('base_table') && $field == $this->view->storage->get('base_field') && empty($alias)) {
+    if ($table == $this->view->storage->get('baseTable') && $field == $this->view->storage->get('base_field') && empty($alias)) {
       $alias = $this->view->storage->get('base_field');
     }
 
@@ -1151,10 +1151,10 @@ protected function compileFields($query) {
         $query->addExpression($string, $fieldname, $placeholders);
       }
       elseif ($this->distinct && !in_array($fieldname, $this->groupby)) {
-        $query->addField(!empty($field['table']) ? $field['table'] : $this->view->storage->get('base_table'), $field['field'], $fieldname);
+        $query->addField(!empty($field['table']) ? $field['table'] : $this->view->storage->get('baseTable'), $field['field'], $fieldname);
       }
       elseif (empty($field['aggregate'])) {
-        $query->addField(!empty($field['table']) ? $field['table'] : $this->view->storage->get('base_table'), $field['field'], $fieldname);
+        $query->addField(!empty($field['table']) ? $field['table'] : $this->view->storage->get('baseTable'), $field['field'], $fieldname);
       }
 
       if ($this->get_count_optimized) {
@@ -1174,7 +1174,7 @@ protected function compileFields($query) {
   public function query($get_count = FALSE) {
     // Check query distinct value.
     if (empty($this->no_distinct) && $this->distinct && !empty($this->fields)) {
-      $base_field_alias = $this->addField($this->view->storage->get('base_table'), $this->view->storage->get('base_field'));
+      $base_field_alias = $this->addField($this->view->storage->get('baseTable'), $this->view->storage->get('base_field'));
       $this->addGroupBy($base_field_alias);
       $distinct = TRUE;
     }
@@ -1214,7 +1214,7 @@ public function query($get_count = FALSE) {
     // Go ahead and build the query.
     // db_select doesn't support to specify the key, so use getConnection directly.
     $query = Database::getConnection($target, $key)
-      ->select($this->view->storage->get('base_table'), $this->view->storage->get('base_table'), $options)
+      ->select($this->view->storage->get('baseTable'), $this->view->storage->get('baseTable'), $options)
       ->addTag('views')
       ->addTag('views_' . $this->view->storage->id());
 
@@ -1374,7 +1374,7 @@ function execute(ViewExecutable $view) {
     $count_query->addMetaData('view', $view);
 
     if (empty($this->options['disable_sql_rewrite'])) {
-      $base_table_data = Views::viewsData()->get($this->view->storage->get('base_table'));
+      $base_table_data = Views::viewsData()->get($this->view->storage->get('baseTable'));
       if (isset($base_table_data['table']['base']['access query tag'])) {
         $access_tag = $base_table_data['table']['base']['access query tag'];
         $query->addTag($access_tag);
@@ -1470,10 +1470,10 @@ public function getEntityTables() {
     // Start with the base table.
     $entity_tables = array();
     $views_data = Views::viewsData();
-    $base_table_data = $views_data->get($this->view->storage->get('base_table'));
+    $base_table_data = $views_data->get($this->view->storage->get('baseTable'));
     if (isset($base_table_data['table']['entity type'])) {
-      $entity_tables[$this->view->storage->get('base_table')] = array(
-        'base' => $this->view->storage->get('base_table'),
+      $entity_tables[$this->view->storage->get('baseTable')] = array(
+        'base' => $this->view->storage->get('baseTable'),
         'relationship_id' => 'none',
         'entity_type' => $base_table_data['table']['entity type'],
         'revision' => FALSE,
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/relationship/GroupwiseMax.php b/core/modules/views/lib/Drupal/views/Plugin/views/relationship/GroupwiseMax.php
index 8aca1f0..dda1eef 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/relationship/GroupwiseMax.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/relationship/GroupwiseMax.php
@@ -161,7 +161,7 @@ public function buildOptionsForm(&$form, &$form_state) {
    * We use this to obtain our subquery SQL.
    */
   protected function getTemporaryView() {
-    $view = entity_create('view', array('base_table' => $this->definition['base']));
+    $view = entity_create('view', array('baseTable' => $this->definition['base']));
     $view->addDisplay('default');
     return $view->getExecutable();
   }
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/row/EntityRow.php b/core/modules/views/lib/Drupal/views/Plugin/views/row/EntityRow.php
index 363bc0c..2402989 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/row/EntityRow.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/row/EntityRow.php
@@ -78,7 +78,7 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
 
     $this->entityType = $this->definition['entity_type'];
     $this->entityInfo = $this->entityManager->getDefinition($this->entityType);
-    $this->base_table = $this->entityInfo['base_table'];
+    $this->base_table = $this->entityInfo['baseTable'];
     $this->base_field = $this->entityInfo['entity_keys']['id'];
   }
 
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
index c3ccf92..72b16b2 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/wizard/WizardPluginBase.php
@@ -28,7 +28,7 @@
    *
    * @var string
    */
-  protected $base_table;
+  protected $baseTable;
 
   /**
    * The entity type connected with the wizard.
@@ -116,11 +116,11 @@
   public function __construct(array $configuration, $plugin_id, array $plugin_definition) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
 
-    $this->base_table = $this->definition['base_table'];
+    $this->baseTable = $this->definition['baseTable'];
 
     $entities = entity_get_info();
     foreach ($entities as $entity_type => $entity_info) {
-      if (isset($entity_info['base_table']) && $this->base_table == $entity_info['base_table']) {
+      if (isset($entity_info['baseTable']) && $this->baseTable == $entity_info['baseTable']) {
         $this->entity_info = $entity_info;
         $this->entity_type = $entity_type;
       }
@@ -201,8 +201,8 @@ public function getSorts() {
    * {@inheritdoc} Drupal\views\Plugin\views\wizard\WizardInterface::buildForm().
    */
   public function buildForm(array $form, array &$form_state) {
-    $style_options = views_fetch_plugin_names('style', 'normal', array($this->base_table));
-    $feed_row_options = views_fetch_plugin_names('row', 'feed', array($this->base_table));
+    $style_options = views_fetch_plugin_names('style', 'normal', array($this->baseTable));
+    $feed_row_options = views_fetch_plugin_names('row', 'feed', array($this->baseTable));
     $path_prefix = url(NULL, array('absolute' => TRUE));
 
     // Add filters and sorts which apply to the view as a whole.
@@ -544,7 +544,7 @@ protected function buildFormStyle(array &$form, array &$form_state, $type) {
    */
   protected function rowStyleOptions() {
     // Get all available row plugins by default.
-    $options = views_fetch_plugin_names('row', 'normal', array($this->base_table));
+    $options = views_fetch_plugin_names('row', 'normal', array($this->baseTable));
     return $options;
   }
 
@@ -623,7 +623,7 @@ protected function instantiateView($form, &$form_state) {
       'id' => $form_state['values']['id'],
       'label' => $form_state['values']['label'],
       'description' => $form_state['values']['description'],
-      'base_table' => $this->base_table,
+      'baseTable' => $this->baseTable,
       'langcode' => language_default()->id,
     );
 
@@ -761,7 +761,7 @@ protected function defaultDisplayOptions() {
     // Add a least one field so the view validates and the user has a preview.
     // The base field can provide a default in its base settings; otherwise,
     // choose the first field with a field handler.
-    $data = Views::viewsData()->get($this->base_table);
+    $data = Views::viewsData()->get($this->baseTable);
     if (isset($data['table']['base']['defaults']['field'])) {
       $default_field = $data['table']['base']['defaults']['field'];
     }
@@ -773,7 +773,7 @@ protected function defaultDisplayOptions() {
       }
     }
     $display_options['fields'][$default_field] = array(
-      'table' => $this->base_table,
+      'table' => $this->baseTable,
       'field' => $default_field,
       'id' => $default_field,
     );
@@ -838,9 +838,9 @@ protected function defaultDisplayFiltersUser(array $form, array &$form_state) {
       // the base table for the view; the taxonomy vocabulary machine_name, for
       // example, is stored in taxonomy_vocabulary, not taxonomy_term_data.
       module_load_include('inc', 'views_ui', 'admin');
-      $fields = Views::viewsDataHelper()->fetchFields($this->base_table, 'filter');
-      if (isset($fields[$this->base_table . '.' . $bundle_key])) {
-        $table = $this->base_table;
+      $fields = Views::viewsDataHelper()->fetchFields($this->baseTable, 'filter');
+      if (isset($fields[$this->baseTable . '.' . $bundle_key])) {
+        $table = $this->baseTable;
       }
       else {
         foreach ($fields as $field_name => $value) {
@@ -928,7 +928,7 @@ protected function defaultDisplaySortsUser($form, $form_state) {
         $column = $column[1];
       }
       else {
-        $table = $this->base_table;
+        $table = $this->baseTable;
         $column = $column[0];
       }
 
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerAllTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerAllTest.php
index 7ad88da..6b03fea 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerAllTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerAllTest.php
@@ -60,7 +60,7 @@ public function testHandlers() {
         continue;
       }
 
-      $view = entity_create('view', array('base_table' => $base_table));
+      $view = entity_create('view', array('baseTable' => $base_table));
       $view = $view->getExecutable();
 
       // @todo The groupwise relationship is currently broken.
diff --git a/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php b/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php
index a712218..907a504 100644
--- a/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/ViewExecutableTest.php
@@ -46,7 +46,7 @@ class ViewExecutableTest extends ViewUnitTestBase {
     'name',
     'description',
     'tag',
-    'base_table',
+    'baseTable',
     'label',
     'core',
     'display',
diff --git a/core/modules/views/lib/Drupal/views/Tests/ViewStorageTest.php b/core/modules/views/lib/Drupal/views/Tests/ViewStorageTest.php
index 4df0def..c07d433e 100644
--- a/core/modules/views/lib/Drupal/views/Tests/ViewStorageTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/ViewStorageTest.php
@@ -32,7 +32,7 @@ class ViewStorageTest extends ViewUnitTestBase {
     'id',
     'description',
     'tag',
-    'base_table',
+    'baseTable',
     'label',
     'core',
     'display',
@@ -270,7 +270,7 @@ protected function displayMethodTests() {
     $this->assertTrue($executable->displayHandlers->get('feed_1')->default_display instanceof DefaultDisplay);
 
     // Tests item related methods().
-    $view = $this->controller->create(array('base_table' => 'views_test_data'));
+    $view = $this->controller->create(array('baseTable' => 'views_test_data'));
     $view->addDisplay('default');
     $view = $view->getExecutable();
 
@@ -349,7 +349,7 @@ public function testCreateDuplicate() {
       'disabled',
       'description',
       'tag',
-      'base_table',
+      'baseTable',
       'label',
       'core',
     );
diff --git a/core/modules/views/lib/Drupal/views/Tests/Wizard/WizardPluginBaseUnitTest.php b/core/modules/views/lib/Drupal/views/Tests/Wizard/WizardPluginBaseUnitTest.php
index 8d2fad6..d68666b 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Wizard/WizardPluginBaseUnitTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Wizard/WizardPluginBaseUnitTest.php
@@ -76,7 +76,7 @@ public function testCreateView() {
       'id' => $random_id,
       'label' => $random_label,
       'description' => $random_description,
-      'base_table' => 'views_test_data',
+      'baseTable' => 'views_test_data',
     );
 
     $this->wizard->validateView($form, $form_state);
@@ -85,7 +85,7 @@ public function testCreateView() {
     $this->assertEqual($view->get('id'), $random_id);
     $this->assertEqual($view->get('label'), $random_label);
     $this->assertEqual($view->get('description'), $random_description);
-    $this->assertEqual($view->get('base_table'), 'views_test_data');
+    $this->assertEqual($view->get('baseTable'), 'views_test_data');
     $this->assertEqual($view->get('langcode'), 'it');
   }
 }
diff --git a/core/modules/views/lib/Drupal/views/ViewExecutable.php b/core/modules/views/lib/Drupal/views/ViewExecutable.php
index 0ce6a2c..cb3d272 100644
--- a/core/modules/views/lib/Drupal/views/ViewExecutable.php
+++ b/core/modules/views/lib/Drupal/views/ViewExecutable.php
@@ -802,7 +802,7 @@ public function renderPager($exposed_input) {
    */
   public function getBaseTables() {
     $base_tables = array(
-      $this->storage->get('base_table') => TRUE,
+      $this->storage->get('baseTable') => TRUE,
       '#global' => TRUE,
     );
 
@@ -999,7 +999,7 @@ public function initQuery() {
     }
 
     // Create and initialize the query object.
-    $views_data = Views::viewsData()->get($this->storage->get('base_table'));
+    $views_data = Views::viewsData()->get($this->storage->get('baseTable'));
     $this->storage->set('base_field', !empty($views_data['table']['base']['field']) ? $views_data['table']['base']['field'] : '');
     if (!empty($views_data['table']['base']['database'])) {
       $this->base_database = $views_data['table']['base']['database'];
diff --git a/core/modules/views/lib/Drupal/views/ViewsDataHelper.php b/core/modules/views/lib/Drupal/views/ViewsDataHelper.php
index b986746..223360c 100644
--- a/core/modules/views/lib/Drupal/views/ViewsDataHelper.php
+++ b/core/modules/views/lib/Drupal/views/ViewsDataHelper.php
@@ -23,7 +23,7 @@ class ViewsDataHelper {
   protected $data;
 
   /**
-   * A prepared list of all fields, keyed by base_table and handler type.
+   * A prepared list of all fields, keyed by baseTable and handler type.
    *
    * @param array
    */
@@ -43,7 +43,7 @@ public function __construct(ViewsData $views_data) {
    * Fetches a list of all fields available for a given base type.
    *
    * @param (array|string) $base
-   *   A list or a single base_table, for example node.
+   *   A list or a single baseTable, for example node.
    * @param string $type
    *   The handler type, for example field or filter.
    * @param bool $grouping
@@ -53,7 +53,7 @@ public function __construct(ViewsData $views_data) {
    *   header only, instead of header, footer, and empty regions.
    *
    * @return array
-   *   A keyed array of in the form of 'base_table' => 'Description'.
+   *   A keyed array of in the form of 'baseTable' => 'Description'.
    */
   public function fetchFields($base, $type, $grouping = FALSE, $sub_type = NULL) {
     if (!$this->fields) {
diff --git a/core/modules/views/views.module b/core/modules/views/views.module
index 26a9dbb..faebbfa 100644
--- a/core/modules/views/views.module
+++ b/core/modules/views/views.module
@@ -869,7 +869,7 @@ function views_library_info() {
  *   An array of possible base tables.
  *
  * @return
- *   A keyed array of in the form of 'base_table' => 'Description'.
+ *   A keyed array of in the form of 'baseTable' => 'Description'.
  */
 function views_fetch_plugin_names($type, $key = NULL, $base = array()) {
   $definitions = Views::pluginManager($type)->getDefinitions();
diff --git a/core/modules/views/views.tokens.inc b/core/modules/views/views.tokens.inc
index 91a53c6..5b177d5 100644
--- a/core/modules/views/views.tokens.inc
+++ b/core/modules/views/views.tokens.inc
@@ -105,7 +105,7 @@ function views_tokens($type, $tokens, array $data = array(), array $options = ar
           }
           break;
         case 'base-table':
-          $replacements[$original] = $view->storage->get('base_table');
+          $replacements[$original] = $view->storage->get('baseTable');
           break;
         case 'base-field':
           $replacements[$original] = $view->storage->get('base_field');
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
index 5995f65..8e21410 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
@@ -245,7 +245,7 @@ public function autocompleteTag(Request $request) {
    */
   public function edit(ViewUI $view, $display_id = NULL) {
     $name = $view->label();
-    $data = $this->viewsData->get($view->get('base_table'));
+    $data = $this->viewsData->get($view->get('baseTable'));
 
     if (isset($data['table']['base']['title'])) {
       $name .= ' (' . $data['table']['base']['title'] . ')';
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigItem.php b/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigItem.php
index 2be9fbc..42fa949 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigItem.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigItem.php
@@ -113,7 +113,7 @@ public function buildForm(array $form, array &$form_state) {
         if (!empty($relationship_options)) {
           // Make sure the existing relationship is even valid. If not, force
           // it to none.
-          $base_fields = Views::viewsDataHelper()->fetchFields($view->get('base_table'), $form_state['type'], $executable->display_handler->useGroupBy());
+          $base_fields = Views::viewsDataHelper()->fetchFields($view->get('baseTable'), $form_state['type'], $executable->display_handler->useGroupBy());
           if (isset($base_fields[$item['table'] . '.' . $item['field']])) {
             $relationship_options = array_merge(array('none' => $this->t('Do not use a relationship')), $relationship_options);
           }
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/EditDetails.php b/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/EditDetails.php
index 3c011f3..134c9e4 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/EditDetails.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/EditDetails.php
@@ -87,8 +87,8 @@ public function submitForm(array &$form, array &$form_state) {
     $bases = Views::viewsData()->fetchBaseTables();
     $form_state['#page_title'] = $view->label();
 
-    if (isset($bases[$view->get('base_table')])) {
-      $form_state['#page_title'] .= ' (' . $bases[$view->get('base_table')]['title'] . ')';
+    if (isset($bases[$view->get('baseTable')])) {
+      $form_state['#page_title'] .= ' (' . $bases[$view->get('baseTable')]['title'] . ')';
     }
 
     $view->cacheSet();
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php b/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
index f926d8d..b26aa85 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
@@ -425,7 +425,7 @@ public function getDisplayDetails($view, $display) {
           "#suffix" => '</li>',
         );
 
-        foreach (views_fetch_plugin_names('display', NULL, array($view->get('storage')->get('base_table'))) as $type => $label) {
+        foreach (views_fetch_plugin_names('display', NULL, array($view->get('storage')->get('baseTable'))) as $type => $label) {
           if ($type == $display['display_plugin']) {
             continue;
           }
@@ -712,7 +712,7 @@ public function renderDisplayTop(ViewUI $view) {
     }
 
     // Buttons for adding a new display.
-    foreach (views_fetch_plugin_names('display', NULL, array($view->get('base_table'))) as $type => $label) {
+    foreach (views_fetch_plugin_names('display', NULL, array($view->get('baseTable'))) as $type => $label) {
       $element['add_display'][$type] = array(
         '#type' => 'submit',
         '#value' => $this->t('Add !display', array('!display' => $label)),

diff --git a/core/lib/Drupal/Core/Entity/Query/Sql/Query.php b/core/lib/Drupal/Core/Entity/Query/Sql/Query.php
index debc403..882bba6 100644
--- a/core/lib/Drupal/Core/Entity/Query/Sql/Query.php
+++ b/core/lib/Drupal/Core/Entity/Query/Sql/Query.php
@@ -111,32 +111,32 @@ public function execute() {
   protected function prepare() {
     $entity_type = $this->entityType;
     $this->entityInfo = $this->entityManager->getDefinition($entity_type);
-    if (!isset($this->entityInfo['base_table'])) {
+    if (!isset($this->entityInfo['baseTable'])) {
       throw new QueryException("No base table, invalid query.");
     }
-    $base_table = $this->entityInfo['base_table'];
+    $base_table = $this->entityInfo['baseTable'];
     $simple_query = TRUE;
     if (isset($this->entityInfo['data_table'])) {
       $simple_query = FALSE;
     }
-    $this->sqlQuery = $this->connection->select($base_table, 'base_table', array('conjunction' => $this->conjunction));
+    $this->sqlQuery = $this->connection->select($base_table, 'baseTable', array('conjunction' => $this->conjunction));
     $this->sqlQuery->addMetaData('entity_type', $entity_type);
     $id_field = $this->entityInfo['entity_keys']['id'];
     // Add the key field for fetchAllKeyed().
     if (empty($this->entityInfo['entity_keys']['revision'])) {
       // When there is no revision support, the key field is the entity key.
-      $this->sqlFields["base_table.$id_field"] = array('base_table', $id_field);
+      $this->sqlFields["baseTable.$id_field"] = array('baseTable', $id_field);
       // Now add the value column for fetchAllKeyed(). This is always the
       // entity id.
-      $this->sqlFields["base_table.$id_field" . '_1'] = array('base_table', $id_field);
+      $this->sqlFields["baseTable.$id_field" . '_1'] = array('baseTable', $id_field);
     }
     else {
       // When there is revision support, the key field is the revision key.
       $revision_field = $this->entityInfo['entity_keys']['revision'];
-      $this->sqlFields["base_table.$revision_field"] = array('base_table', $revision_field);
+      $this->sqlFields["baseTable.$revision_field"] = array('baseTable', $revision_field);
       // Now add the value column for fetchAllKeyed(). This is always the
       // entity id.
-      $this->sqlFields["base_table.$id_field"] = array('base_table', $id_field);
+      $this->sqlFields["baseTable.$id_field"] = array('baseTable', $id_field);
     }
     if ($this->accessCheck) {
       $this->sqlQuery->addTag($entity_type . '_access');
@@ -279,13 +279,13 @@ protected function result() {
    *
    * @return string
    *   An expression that will select the given field for the given language in
    *   a SELECT query, such as 'base_table.id'.
    */
   protected function getSqlField($field, $langcode) {
     if (!isset($this->tables)) {
       $this->tables = $this->getTables($this->sqlQuery);
     }
-    $base_property = "base_table.$field";
+    $base_property = "baseTable.$field";
     if (isset($this->sqlFields[$base_property])) {
       return $base_property;
     }
@@ -279,13 +279,13 @@ protected function result() {
    * @return string
    *   An expression that will select the given field for the given language in
-   *   a SELECT query, such as 'base_table.id'.
+   *   a SELECT query, such as 'baseTable.id'.
    */
   protected function getSqlField($field, $langcode) {
diff --git a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
index 6f09d6f..5040453 100644
--- a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
+++ b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
@@ -56,7 +56,7 @@ class Field extends FieldPluginBase {
   public $limit_values;
 
   /**
-   * A shortcut for $view->base_table.
+   * A shortcut for $view->baseTable.
    *
    * @var string
    */
@@ -150,15 +150,15 @@ public function access() {
   }
 
   /**
    * Set the base_table and base_table_alias.
    *
    * @return string
    *   The base table which is used in the current view "context".
    */
   function get_base_table() {
     if (!isset($this->base_table)) {
-      // This base_table is coming from the entity not the field.
-      $this->base_table = $this->view->storage->get('base_table');
+      // This baseTable is coming from the entity not the field.
+      $this->base_table = $this->view->storage->get('baseTable');
 
       // If the current field is under a relationship you can't be sure that the
       // base table of the view is the base table of the current field.
@@ -150,15 +150,15 @@ public function access() {
 
   /**
-   * Set the base_table and base_table_alias.
+   * Set the baseTable and base_table_alias.
    *
    * @return string
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/TaxonomyIndexTid.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/TaxonomyIndexTid.php
index 8cbb9fb..0790bea 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/TaxonomyIndexTid.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/field/TaxonomyIndexTid.php
@@ -27,8 +27,8 @@ class TaxonomyIndexTid extends PrerenderList {
   public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
     parent::init($view, $display, $options);
 
-    // @todo: Wouldn't it be possible to use $this->base_table and no if here?
-    if ($view->storage->get('base_table') == 'node_field_revision') {
+    // @todo: Wouldn't it be possible to use $this->baseTable and no if here?
+    if ($view->storage->get('baseTable') == 'node_field_revision') {
       $this->additional_fields['nid'] = array('table' => 'node_field_revision', 'field' => 'nid');
     }
     else {